package com.goomood.phm.service;

import java.util.List;
import com.goomood.phm.domain.TechType;

/**
 * 资料类型Service接口
 * 
 * @author goomood
 * @date 2024-11-16
 */
public interface ITechTypeService 
{
    /**
     * 查询资料类型
     * 
     * @param id 资料类型主键
     * @return 资料类型
     */
    public TechType selectTechTypeById(Long id);

    /**
     * 查询资料类型列表
     * 
     * @param techType 资料类型
     * @return 资料类型集合
     */
    public List<TechType> selectTechTypeList(TechType techType);

    /**
     * 新增资料类型
     * 
     * @param techType 资料类型
     * @return 结果
     */
    public int insertTechType(TechType techType);

    /**
     * 修改资料类型
     * 
     * @param techType 资料类型
     * @return 结果
     */
    public int updateTechType(TechType techType);

    /**
     * 批量删除资料类型
     * 
     * @param ids 需要删除的资料类型主键集合
     * @return 结果
     */
    public int deleteTechTypeByIds(Long[] ids);

    /**
     * 删除资料类型信息
     * 
     * @param id 资料类型主键
     * @return 结果
     */
    public int deleteTechTypeById(Long id);
}
